package de.intevation.gnv.artifacts.services.requestobjects;

import java.util.Collection;

/**
 * This is the interface description for a fis. Currently, there are three
 * methods defined which need to be implemented by concrete classes:<br>
 * <ol>
 *  <li>getID(): Returns the id of this fis.</li>
 *  <li>getParameter(): Returns a collection of parameter.</li>
 *  <li>addParameter(Collection<Parameter>): Adds a parameter collection to this
 * fis.</li>
 * </ol>
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public interface FIS {

    /**
     * Returns the id of this FIS
     * @return the id of this fis.
     */
    String getID();

    /**
     * Returns a collection of Parameters which belongs to the FIS.
     * @return a collection of parameters.
     */
    Collection<Parameter> getParameter();

    /**
     * Add a collection of parameters to this fis.
     *
     * @param parameter Some parameters.
     */
    void addParameter(Collection<Parameter> parameter);

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
